==> core_explore_keyword_registry_app-1.0.0a1.tar.gz: core_explore_keyword_registry_app-1.0.0a1/core_explore_keyword_registry_app/views/user/forms.py <==
""" Refinement Form.
"""
from django import forms

from core_main_registry_app.components.category import api as category_api
from core_main_registry_app.components.refinement import api as refinement_api
from core_main_registry_app.components.template import api as template_registry_api
from core_main_registry_app.utils.fancytree.widget import FancyTreeWidget


class RefinementForm(forms.Form):
    prefix = 'refinement'

    def __init__(self, *args, **kwargs):
        super(RefinementForm, self).__init__(*args, **kwargs)
        # Get global template.
        template = template_registry_api.get_current_registry_template()
        # Get refinements.
        refinements = refinement_api.get_all_filtered_by_template_hash(template.hash)
        for refinement in refinements:
            categories = category_api.get_all_filtered_by_refinement_id(refinement.id)
            self.fields[refinement.slug] = forms.ModelMultipleChoiceField(queryset=categories,
                                                                          required=False,
                                                                          label=refinement.name,
                                                                          widget=FancyTreeWidget(
                                                                              queryset=categories))

            self.fields[refinement.slug].has_selected_values = \
                kwargs.get('data').get("{0}-{1}".format(self.prefix, refinement.slug)) is not None

==> core_explore_keyword_registry_app-1.6.0.tar.gz: core_explore_keyword_registry_app-1.6.0/core_explore_keyword_registry_app/views/user/forms.py <==
""" Refinement Form.
"""
from django import forms

from core_main_registry_app.components.category import api as category_api
from core_main_registry_app.components.refinement import api as refinement_api
from core_main_registry_app.components.template import api as template_registry_api
from core_main_registry_app.utils.fancytree.widget import FancyTreeWidget


class RefinementForm(forms.Form):
    prefix = 'refinement'

    def __init__(self, *args, **kwargs):
        super(RefinementForm, self).__init__(*args, **kwargs)
        # Get global template.
        template = template_registry_api.get_current_registry_template()
        # Get refinements.
        refinements = refinement_api.get_all_filtered_by_template_hash(template.hash)
        for refinement in refinements:
            categories = category_api.get_all_filtered_by_refinement_id(refinement.id)
            self.fields[refinement.slug] = forms.ModelMultipleChoiceField(queryset=categories,
                                                                          required=False,
                                                                          label=refinement.name,
                                                                          widget=FancyTreeWidget(
                                                                              queryset=categories,
                                                                              count_mode=True))

            self.fields[refinement.slug].has_selected_values = \
                kwargs.get('data').get("{0}-{1}".format(self.prefix, refinement.slug)) is not None
